@@ -1,6 +1,6 @@
 /*
  * happydigger - program for cataloging archaeological finds
- * Copyright (C) 2004, 2005 Joop Stakenborg <pg4i@amsat.org>
+ * Copyright (C) 2004, 2005, 2007 Joop Stakenborg <pg4i@amsat.org>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -14,7 +14,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA
  */
 
 #include <gtk/gtk.h>
@@ -26,13 +26,18 @@
 #include <sqlite3.h>
 
 #include "interface.h"
-#include "support.h"
+#include "utils.h"
 #include "callbacks.h"
 #include "db.h"
 #include "preferences.h"
 #include "gui_utils.h"
 #include "gui_warningdialog.h"
 
+#ifdef WIN32
+#include <windows.h>
+#include <shlobj.h>
+#endif
+
 GtkWidget *window, *startupwindow = NULL;
 sqlite3 *db;
 statestype state;
@@ -44,19 +49,24 @@ dircheck (void)
 {
 	struct stat statdir;
 	gchar *mddir;
-																																								
+
 	mddir = g_strdup_printf ("%s%s.%s", 
 		g_get_home_dir (), G_DIR_SEPARATOR_S, PACKAGE);
 	if (stat (mddir, &statdir) == -1)
 	{
+#ifdef WIN32
+		if (mkdir (mddir) == -1)
+			g_error (_("Creating ~/.%s directory."), PACKAGE);
+#else
 		if (mkdir (mddir, S_IRUSR | S_IWUSR | S_IXUSR) == -1)
 			g_error (_("Creating ~/.%s directory."), PACKAGE);
+#endif
 	}
 	else if (!S_ISDIR (statdir.st_mode))
 		g_error (_("~/.%s is not a directory."), PACKAGE);
 }
 
-/* limit length of textviews to 220 characters */
+/* limit length of textviews to 500 characters */
 void text_changed (GtkTextBuffer *textbuffer, gpointer user_data)
 {
 	GtkTextIter first, last, start, stop;
@@ -65,7 +75,7 @@ void text_changed (GtkTextBuffer *textbuffer, gpointer user_data)
 
 	gtk_text_buffer_get_bounds (textbuffer, &first, &last);
 	text = gtk_text_buffer_get_text (textbuffer, &first, &last, FALSE);
-	if (strlen(text) == 220)
+	if (strlen(text) == 500)
 	{
 		mark = gtk_text_buffer_get_insert (textbuffer);
 		gtk_text_buffer_get_iter_at_mark (textbuffer, &stop, mark);
@@ -77,12 +87,12 @@ void text_changed (GtkTextBuffer *textbuffer, gpointer user_data)
 	gtk_text_buffer_get_bounds (textbuffer, &first, &last);
 	gtk_text_buffer_apply_tag_by_name (textbuffer, "tiny", &first, &last);
 }
-																																						
+
 int
 main (int argc, char *argv[])
 {
-	GtkWidget *entry, *notes, *spotnotes, *identry, *tablecombo;
-	gchar *filename, *id, *msg, *title;
+	GtkWidget *entry, *notes, *spotnotes, *identry, *tablecombo, *label, *widget;
+	gchar *filename, *id, *msg, *title, *dom;
 	gint result, rc;
 	GtkTextBuffer *buffer;
 
@@ -97,22 +107,31 @@ main (int argc, char *argv[])
 		return -1;
 	}
 
-#ifdef ENABLE_NLS
-	bindtextdomain (PACKAGE, PACKAGE_LOCALE_DIR);
+	setlocale (LC_ALL, "");
+#ifdef WIN32
+	dom = bindtextdomain (PACKAGE, ".");
+#else
+	dom = bindtextdomain (PACKAGE, PACKAGE_LOCALE_DIR);
+#endif
 	bind_textdomain_codeset (PACKAGE, "UTF-8");
 	textdomain (PACKAGE);
-#endif
 
 	gtk_set_locale ();
 	gtk_init (&argc, &argv);
 
+#ifdef WIN32
+	add_pixmap_directory (".");
+#else
 	add_pixmap_directory (PACKAGE_DATA_DIR "/pixmaps");
+#endif
 	window = create_window ();
 	gtk_widget_realize (window);
 	
 	loadpreferences ();
 	state.imageloaddir = g_strconcat (g_get_home_dir(), G_DIR_SEPARATOR_S, NULL);
 	state.table = g_strdup ("finds");
+	state.webmapdir = g_strconcat (g_get_home_dir(), G_DIR_SEPARATOR_S, NULL);
+	state.sortby = g_strdup ("find");
 
 	/* fill in combo strings */
 	set_combostrings ();
@@ -138,6 +157,7 @@ main (int argc, char *argv[])
 			sqlite3_close (db);
 			g_free (state.imageloaddir);
 			g_free (state.table);
+			g_free (state.webmapdir);
 			gtk_main_quit ();
 		}
 		else
@@ -153,10 +173,14 @@ main (int argc, char *argv[])
 	}
 	else
 	{	/* find current tables in the database and add to the combobox */
-		startupwindow = create_startupwindow ();
+		startupwindow = create_startupdialog ();
 		find_tables ();
 		tablecombo = lookup_widget (startupwindow, "tablecombo");
 		gtk_combo_box_set_active (GTK_COMBO_BOX(tablecombo), 0);
+		gtk_entry_set_activates_default
+			(GTK_ENTRY (gtk_bin_get_child (GTK_BIN (tablecombo))), TRUE);
+		gtk_dialog_set_default_response
+			(GTK_DIALOG (startupwindow), GTK_RESPONSE_OK);
 		gtk_widget_show (startupwindow);
 	}
 
@@ -169,6 +193,20 @@ main (int argc, char *argv[])
 	gtk_text_buffer_create_tag (buffer, "tiny", "size", 8 * PANGO_SCALE, NULL);
 	g_signal_connect (G_OBJECT (buffer), "changed", G_CALLBACK (text_changed), NULL);
 
+	label = lookup_widget (window, "label6");
+	widget = lookup_widget (window, "typecombo");
+	gtk_label_set_mnemonic_widget (GTK_LABEL (label), widget);
+	label = lookup_widget (window, "label7");
+	widget = lookup_widget (window, "materialcombo");
+	gtk_label_set_mnemonic_widget (GTK_LABEL (label), widget);
+	label = lookup_widget (window, "label14");
+	widget = lookup_widget (window, "periodcombo");
+	gtk_label_set_mnemonic_widget (GTK_LABEL (label), widget);
+	label = lookup_widget (window, "label13");
+	gtk_label_set_mnemonic_widget (GTK_LABEL (label), notes);
+	label = lookup_widget (window, "label12");
+	gtk_label_set_mnemonic_widget (GTK_LABEL (label), spotnotes);
+
 /* uncomment next for debugging purposes */
 	gtk_widget_hide (identry);
 
